@@ -205,7 +205,7 @@ G - G-language Genome Analysis Environment core interface module
    
  $gb->seq_info();                # Prints the basic sequence information.
 
- $find_ori_ter($gb);      # Give $gb as the first argument to 
+ $find_ori_ter($gb);             # Give $gb as the first argument to 
                                  # most of the analysis functions
 
 
@@ -213,9 +213,7 @@ G - G-language Genome Analysis Environment core interface module
 
  The G-language GAE fully supports most sequence databases.
 
-=head2 stored annotation information:
-
-=over 4   
+ Stored annotation information:
 
  LOCUS  
          $gb->{LOCUS}->{id}              -accession number 
@@ -271,13 +269,12 @@ G - G-language Genome Analysis Environment core interface module
  SEQ  
          $gb->{SEQ}              -sequence data following "ORIGIN" 
 
-=back
 
-=head2 supported methods of G-language Genome Analysis Environment
+=head1 Supported methods of G-language Genome Analysis Environment
 
-=over 2
+=cut
 
-=item new()
+=head2 $gb = new G("genome file")
 
          Creates a G instance.
          First option is the filename of the database. Default format is
@@ -294,16 +291,10 @@ G - G-language Genome Analysis Environment core interface module
 
            'force cache'             rebuilds database cache.
 
-           'without annotation'      this option skips the annotation.
-
            'multiple locus'          this option merges multiple loci in the 
                                      database and load the information
                                      as G-language instance.
 
-           'long sequence'           this option uses a pointer of the filehandle 
-                                     to read the genome sequence. See 
-                                     next_seq() method below for details.
-
            'bioperl'                 this option creates a G instance from 
                                      a bioperl object. 
                                      eg. $bp = $bp->next_seq();       # bioperl
@@ -336,196 +327,325 @@ G - G-language Genome Analysis Environment core interface module
                                 pass to new() function will be the accession 
                                 number of the database.
 
-=item output()
+=cut
+
+=head2 $gb->output()
 
          Given a filename and an option, outputs the G-language data object 
          to the specified file in a flat-file database of a given format.
          The options are the same as those of new().  Default format is 'GenBank'.
+
          eg. $gb->output("my_genome.embl", "EMBL");
              $gb->output("my_genome.gbk"); # with GenBank you can ommit the option.
 
-=item complement()
+=cut
+
+=head2 complement
 
          Given a sequence, returns its complement.
-         eg. complement('atgc');  returns 'gcat'
 
-=item translate()
+         eg. complement('atgc');  # returns 'gcat'
+
+=cut
+
+=head2 translate
 
          Given a sequence, returns its translated sequence.
          Regular codon table is used.
-         eg. translate('ctggtg'); returns 'LV'
+         eg. translate('ctggtg');  # returns 'LV'
 
-=item $gb->seq_info()
+=cut
+
+=head2 $gb->seq()
+
+         Returns the entire sequence. Same as $gb->{SEQ};
+
+=cut
+
+=head2 $gb->seq_info()
 
          Prints the basic information of the genome to STDOUT.
 
-=item $gb->DESTROY()
+=cut
 
-         Destroys the G instance
-
-=item $gb->del_key()
-
-         Given a object, deletes it from the G instance structure
-         eg. $gb->del_key('FEATURE1'); deletes 'FEATURE1' hash
-
-=item $gb->getseq()
+=head2 $gb->getseq()
 
          Given the start and end positions (starting from 0 as in Perl),
          returns the sequence specified.
-         eg. $gb->getseq(1,3); returns the 2nd, 3rd, and 4th nucleotides.
 
-=item $gb->get_gbkseq()
+         eg. $gb->getseq(1,3); # returns the 2nd, 3rd, and 4th nucleotides.
+
+=cut
+
+=head2 $gb->get_gbkseq()
 
          Given the start and end positions (starting from 1 as in 
          Genbank), returns the sequence specified.
-         eg. $gb->get_gbkseq(1,3); returns the 1st, 2nd, and 3rd 
-             nucleotides.
 
-=item $gb->get_cdsseq()
+         eg. $gb->get_gbkseq(1,3); # returns the 1st, 2nd, and 3rd nucleotides.
+
+=cut
+
+=head2 $gb->get_cdsseq()
 
          Given a CDS ID, returns the CDS sequence. 
          'complement' is properly parsed.
-         eg. $gb->get_cdsseq('CDS1'); returns the 'CDS1' sequence.
 
-=item $gb->get_geneseq()
+         eg. $gb->get_cdsseq('CDS1'); # returns the 'CDS1' sequence.
+
+=cut
+
+=head2 $gb->get_geneseq()
 
          Given a CDS ID, returns the CDS sequence, or the exon sequence
          If introns are present.
          'complement' is properly parsed, and introns are spliced out.
-         eg. $gb->get_geneseq('CDS1'); returns the 'CDS1' sequence or 
-             exon.
 
-=item $gb->feature()
+         eg. $gb->get_geneseq('CDS1'); # returns the 'CDS1' sequence or exon.
 
-         Returns the array of all feature object name.
-         foreach ($gb->feature()){
-             $gb->get_cdsseq($_);
-         }
-         prints all feature sequences.
+=cut
 
-=item $gb->cds()
+=head2 $gb->feature()
 
-         Returns the array of all cds object name.
+         Returns the array of all feature IDs.
+         Features are ignored when $gb->{$feature}->{on} is 0.
 
-         !CAUTION! the object name is actually the FEATURE OBJECT NAME,
+         eg.
+           foreach ($gb->feature()){
+               $gb->get_cdsseq($_);
+           }
+           #prints all feature sequences.
+
+         Optionally, feature type can be supplied to return only the
+         specifies features.
+
+         eg. $gb->feature("tRNA"); # returns feature IDs only for tRNAs
+
+         Option of "all" always returns all features regardless of the
+         value of $gb->{$feature}->{on}.
+
+=cut
+
+=head2 $gb->cds()
+
+         Returns the array of all feature IDs of CDS.
+         Features are ignored when $gb->{FEATURE$i}->{on} OR
+         $gb->{CDS$i}->{on} is 0.
+
+         !CAUTION! the object name is actually the FEATURE ID,
          to enable access to all feature values. However, most of the
          time you do not need to be aware of this difference.
 
-         foreach ($gb->cds()){
-             $gb->get_geneseq($_);
-         }
-         prints all gene sequences.
+         eg.
+           foreach ($gb->cds()){
+               $gb->get_geneseq($_);
+           }
+           #prints all gene sequences.
 
-=item $gb->startcodon()
+         Option of "all" always returns all features regardless of the
+         value of $gb->{$feature}->{on}.
 
-         Given a CDS ID, returns the start codon.
-         eg. $gb->startcodon('CDS1'); returns 'atg'
+=cut
 
-=item $gb->stopcodon()
+=head2 $gb->tRNA()
 
-         Given a CDS ID, returns the stop codon.
-         eg. $gb->stopcodon('CDS1'); returns 'tag'
+         Returns the array of all feature IDs of tRNAs.
 
-=item $gb->before_startcodon()
+=cut
 
-         Given a CDS ID and length, returns the sequence upstream of 
-         start codon.
-         eg. $gb->before_startcodon('CDS1', 100); returns 100 bp  
-             sequence upstream of the start codon of 'CDS1'.
+=head2 $gb->rRNA()
 
-=item $gb->after_startcodon()
+         Returns the array of all feature IDs of rRNAs.
 
-         Given a CDS ID and length, returns the sequence downstream of 
-         start codon.
-         eg. $gb->after_startcodon('CDS1', 100); returns 100 bp  
-             sequence downstream of the start codon of 'CDS1'.
+=cut
 
-=item $gb->before_stopcodon()
+=head2 $gb->gene()
 
-         Given a CDS ID and length, returns the sequence upstream of 
-         stop codon.
-         eg. $gb->before_stopcodon('CDS1', 100); returns 100 bp  
-             sequence upstream of the stop codon of 'CDS1'.
+         Returns the array of all feature IDs of genes.
 
-=item $gb->after_stopcodon()
+=cut
 
-         Given a CDS ID and length, returns the sequence downstream of 
-         stop codon.
-         eg. $gb->after_stopcodon('CDS1', 100); returns 100 bp  
-             sequence downstream of the stop codon of 'CDS1'.
+=head2 $gb->next_feature()
 
-=item $gb->get_intron()
+         Given a feature ID, returns the ID of the next feature.
+         Second argument can be used to specify the type of the 
+         next feature.
 
-         Given a CDS ID, returns the intron sequences as array of 
-         sequences.
-         eg. $gb->get_intron('CDS1'); 
-             returns ($1st_intron, $2nd_intron,..)
+         eg. $gb->next_feature(FEATURE1234); # returns 'FEATURE1235'
+             $gb->next_feature(FEATURE1234, 'tRNA'); 
+             # returns next feature ID whose type is 'tRNA'
 
-=item $gb->pos2feature()
+=cut
 
-         Given a GenBank position (sequence starting from position 1) 
-         returns the G-instance ID (ex. FEATURE123) of the feature at
-         the given position. If multiple features exists for the given
-         position, the first feature to appear is returned. Returns 
-         NULL if no feature exists.
+=head2 $gb->next_cds()
 
-=item $gb->pos2gene()
+         Given a feature ID, returns the ID of the next cds.
+         This is same as $gb->next_feature($featureID, 'CDS');
 
-         Given a GenBank position (sequence starting from position 1) 
-         returns the G-instance ID (ex. FEATURE123) of the gene at
-         the given position. If multiple genes exists for the given
-         position, the first gene to appear is returned. Returns 
-         NULL if no gene exists.
+=cut
 
-=item $gb->gene2id()
+=head2 $gb->previous_feature()
 
-         Given a GenBank gene name, returns the G object feature ID
-         (ex. FEATURE123). Returns NULL if no gene exists.
+         Given a feature ID, returns the ID of the previous feature.
+         Second argument can be used to specify the type of the 
+         next feature.
 
-=item $gb->get_exon()
+         eg. $gb->previous_feature(FEATURE1234); # returns 'FEATURE1233'
+             $gb->previous_feature(FEATURE1234, 'tRNA'); 
+             # returns previous feature ID whose type is 'tRNA'
 
-         Given a CDS ID, returns the exon sequence.
-         'complement' is properly parsed, and introns are spliced out.
-         eg. $gb->get_exon('CDS1'); returns the 'CDS1' exon.
+=cut
 
-=item $gb->next_locus()
+=head2 $gb->previous_cds()
 
+         Given a feature ID, returns the ID of the previous cds.
+         This is same as $gb->previous_feature($featureID, 'CDS');
+
+=cut
+
+
+
+
+=head2 $gb->startcodon()
+
+         Given a CDS ID, returns the start codon.
+
+         eg. $gb->startcodon("FEATURE$i"); # returns 'atg'
+
+=cut
+
+=head2 $gb->stopcodon()
+
+         Given a CDS ID, returns the stop codon.
+
+         eg. $gb->stopcodon("FEATURE$i"); # returns 'tag'
+
+=cut
+
+=head2 $gb->before_startcodon()
+
+         Given a CDS ID and length, returns the sequence upstream of 
+         start codon.
+
+         eg. $gb->before_startcodon('CDS1', 100); 
+             # returns 100 bp sequence upstream of the start codon of 'CDS1'.
+
+=cut
+
+=head2 $gb->after_startcodon()
+
+         Given a CDS ID and length, returns the sequence downstream of 
+         start codon.
+
+         eg. $gb->after_startcodon('CDS1', 100); 
+             # returns 100 bp sequence downstream of the start codon of 'CDS1'.
+
+=cut
+
+=head2 $gb->before_stopcodon()
+
+         Given a CDS ID and length, returns the sequence upstream of 
+         stop codon.
+
+         eg. $gb->before_stopcodon('CDS1', 100); 
+             # returns 100 bp sequence upstream of the stop codon of 'CDS1'.
+
+=cut
+
+=head2 $gb->after_stopcodon()
+
+         Given a CDS ID and length, returns the sequence downstream of 
+         stop codon.
+
+         eg. $gb->after_stopcodon('CDS1', 100); 
+             # returns 100 bp sequence downstream of the stop codon of 'CDS1'.
+
+=cut
+
+=head2 $gb->get_exon()
+
+         Given a CDS ID, returns the exon sequence.
+         'complement' is properly parsed, and introns are spliced out.
+
+         eg. $gb->get_exon('CDS1'); returns the 'CDS1' exon.
+
+=cut
+
+
+=head2 $gb->get_intron()
+
+         Given a CDS ID, returns the intron sequences as array of 
+         sequences.
+
+         eg. $gb->get_intron('CDS1'); 
+             # returns ($1st_intron, $2nd_intron,..)
+
+=cut
+
+=head2 $gb->pos2feature()
+
+         Given a GenBank position (sequence starting from position 1) 
+         returns the feature ID (ex. FEATURE123) of the feature at
+         the given position. If multiple features exist for the given
+         position, the first feature to appear is returned. Returns 
+         NULL if no feature exists.
+
+=cut
+
+=head2 $gb->pos2gene()
+
+         Given a GenBank position (sequence starting from position 1) 
+         returns the feature ID (ex. FEATURE123) of the gene at
+         the given position. If multiple genes exists for the given
+         position, the first gene to appear is returned. Returns 
+         NULL if no gene exists.
+
+=cut
+
+=head2 $gb->gene2id()
+
+         Given a GenBank gene name, returns the feature ID (ex. FEATURE123). 
+         Returns NULL if no gene exists.
+
+=cut
+
+=head2 $gb->next_locus()
+
          Reads the next locus.
          the G instance is then updated.
 
-         do{
+         eg. 
+           do{
+  
+           }while($gb->next_locus());
+           #  Enables multiple loci analysis.        
 
-         }while($gb->next_locus());
+=cut
 
-         Enables multiple loci analysis.        
+=head2 $gb->clone()
 
-=item $gb->next_seq()
+         Returns cloned G instance, which is a new G instance with
+         identical data. 
 
-         If G instance is created with 'long sequence' option, 
-         $gb->next_seq() method replace the next chunk of sequence 
-         to $gb->{SEQ}.
+=cut
 
-         while($gb->next_seq(100000)){
-             print $gb->{SEQ};
-         }
+=head2 $gb->DESTROY()
 
-         Enables continuous analysis.
+         Destroys the G instance.
 
-=item $gb->rewind_genome()
+=cut
 
-         If G instance is created with 'long sequence' option, 
-         $gb->rewind_genome() method puts the filehandle pointer back 
-         to the ORIGIN position.
+=head2 $gb->del_key()
 
-=back
+         Given a object, deletes it from the G instance structure
+         eg. $gb->del_key('FEATURE1'); # deletes 'FEATURE1' hash
 
-=head1 AUTHOR
+=cut
 
-Kazuharu Arakawa, gaou@g-language.org
 
-=head1 SEE ALSO
+=head1 AUTHOR
 
-perl(1).
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =cut
 
