@@ -60,11 +60,12 @@ sub buildPDocDB{
     my $gPath = qx/perldoc -l G::Skyline/;
     
     $bpPath =~ s/Perl.pm//;
-    $gPath =~ s/Skyline.pm//;
+    $gPath =~ s/\/Skyline.pm//;
     
     chomp($bpPath);
     chomp($gPath);
-    
+
+    find({"wanted"=>\&process_g, "follow"=>1}, $gPath . '.pm');
     find({"wanted"=>\&process_g, "follow"=>1}, $gPath);
     find({"wanted"=>\&process_bp, "follow"=>1}, $bpPath);
 }
@@ -173,14 +174,13 @@ sub help{
 
 
 
-
 sub process_g{
     next unless(/\.pm$/);
 
     open(FILE, $File::Find::name) || die($!);
     while(<FILE>){
 	chomp;
-	if(/\=head2\s+(\S*)\s*/){
+	if(/\=head2\s+(.*)\s*$/){
 	    my $subname = $1;
 
 	    while(<FILE>){
@@ -254,12 +254,6 @@ unedited.
 
 Blah blah blah.
 
-=head2 EXPORT
-
-None by default.
-
-
-
 =head1 SEE ALSO
 
 Mention other useful documentation such as the documentation of
