@@ -33,21 +33,16 @@ package G::Skyline;
 
 use strict;
 
-BEGIN{
-    eval "use Bio::SeqIO;";
-    if($@){ warn "$@" };
-    eval "use Bio::DB::GenBank;";
-    if($@){ warn "$@" };
-    eval "use Bio::DB::RefSeq;";
-    if($@){ warn "$@" };
-    eval "use Bio::Perl;";
-    if($@){ warn "$@" };
-}
+use Bio::SeqIO;
+use Bio::DB::GenBank;
+use Bio::DB::RefSeq;
+use Bio::Perl;
 
 use G::Messenger;
 use G::DB::SDB;
 use G::IO::Bioperl;
 use G::IO::Annotation;
+
 require G::Prelude;
 require G::IO::GenBankI;
 require G::IO::GenBankO;
@@ -57,7 +52,32 @@ require G::IO::EmblI;
 use File::Basename;
 
 our @ISA = qw(G::Prelude G::IO::GenBankI G::IO::GenBankO);
-our $VERSION = '1.6.6';
+our $VERSION = '1.6.8';
+
+#::::::::::::::::::::::::::::::
+#          Perldoc
+#::::::::::::::::::::::::::::::
+
+=head1 NAME
+
+G::Skyline
+
+=head1 SYNOPSIS
+
+ use G::Skyline;
+ @ISA = (G::Skyline);
+   
+=head1 DESCRIPTION
+
+ Inherits all necessary classes.
+ Intended for internal use only.
+ This is the central core module of G-language GAE.
+
+=head1 AUTHOR
+
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
+
+=cut
 
 #::::::::::::::::::::::::::::::
 #          Variables
@@ -185,6 +205,8 @@ sub new {
 	$this->seq_info() unless($no_msg);
 	$this->{BIOPERL} =  $bp;
     }else{
+
+
 	if ($format eq 'embl'){
 	    $this = new G::IO::EmblI;
 	}elsif ($format eq 'fasta'){
@@ -203,28 +225,30 @@ sub new {
 	*GENBANK = $this->open_gb($filename);
 
 	if ($multiple_locus){
+	    $this = new G::Skyline("blessed");
 	    $tmp = new G::Skyline($filename, "no msg", $format, "no cache");
 	    $this->multi_locus($tmp);
 	    $this->seq_info() unless($no_msg);
 	}else{
 	    if ($without_annotation){
 		$this->goto_origin();
-	    }else{
-		$this->read_locus($locus_msg);
-		$this->read_header();
-		$this->read_features();
-	    }
-	    
-	    if ($long_sequence){
-		$this->{origin} = tell *GENBANK;
-	    }else{
 		$this->getnucs();
 		$this->seq_info() unless ($no_msg);
+		warn("This feature is deprecated. It will be removed in future releases.");
+	    }elsif ($long_sequence){
+		$this->read_locus();
+		$this->read_header();
+		$this->read_features();
+		$this->{origin} = tell *GENBANK;
+		warn("This feature is deprecated. It will be removed in future releases.");
+	    }else{
+		$this->next_locus($no_msg);
 
 		if($force_cache || $no_cache == 0){
 		    sdb_save($this, sprintf("cache-%s-%s-%s", $basename, $stat[7], $stat[9]));
 		}
 	    }
+
 	}
     }
 
@@ -262,21 +286,22 @@ sub loaded_msg {
 
     my $print =
 	qq(
-	     __/__/__/__/__/__/__/__/__/__/__/__/__/
+	     __/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/
                 
-             G-language Genome Analysis Environment
+                   G-language  Genome Analysis Environment v.$VERSION
 
-	      Version: $VERSION
-	      License: GPL
  
-	      Copyright (C) 2001-2007 
-              G-language Project
-	      Institute for Advanced Biosciences,
-	      Keio University, JAPAN 
+                             http://www.g-language.org/
 
-          	 http://www.g-language.org/
+              Please cite: 
+                 Arakawa et al. (2003) Bioinformatics.
+                 Arakawa et al. (2006) Journal of Pestice Science.
 
-	     __/__/__/__/__/__/__/__/__/__/__/__/__/
+ 	      License: GNU General Public License
+	      Copyright (C) 2001-2007 G-language Project
+	      Institute for Advanced Biosciences, Keio University, JAPAN 
+
+	     __/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/
 	   \n);
 
     &msg_error($print);
@@ -437,33 +462,3 @@ sub DESTROY {
 
 1;
 
-__END__
-
-=head1 NAME
-
-G::Skyline
-
-=head1 SYNOPSIS
-
- use G::Skyline;
- @ISA = (G::Skyline);
-   
-=head1 DESCRIPTION
-
- Inherits all necessary classes.
- Intended for internal use only.
-
-=back
-
-=head1 AUTHOR
-
-Kazuharu Gaou Arakawa, gaou@g-language.org
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
